@@ -7,6 +7,7 @@ try:
     from System import Object
     from System.Windows import Forms
     from System import Environment
+    import System.Security.Principal as sec
     import System.Threading.Tasks as tasks
 except ImportError:
     print("Failed to import System.")
@@ -110,6 +111,12 @@ def all_required_inputs(component):
     return not is_input_missing
 
 
+def is_user_admin():
+    """Get a Boolean for whether the current User has Admin access through Rhino."""
+    principal = sec.WindowsPrincipal(sec.WindowsIdentity.GetCurrent())
+    return principal.IsInRole(sec.WindowsBuiltInRole.Administrator)
+
+
 def local_processor_count():
     """Get an integer for the number of processors on this machine.
 
@@ -166,7 +173,7 @@ def run_function_in_parallel(parallel_function, object_count, cpu_count=None):
         obj_groups = [[x, x + i_per_group] for x in range(0, object_count, i_per_group)]
         obj_groups[-1][-1] = object_count  # ensure the last group ends with obj count
 
-    if cpu_count is None:  # use all availabe CPUs
+    if cpu_count is None:  # use all available CPUs
         tasks.Parallel.ForEach(range(object_count), parallel_function)
     elif cpu_count <= 1:  # run everything on a single processor
         for i in range(object_count):
